package tls-async

  1. Overview
  2. Docs

Module Authenticator.ParamSource

Sourcetype t
Sourceval ca_file : ?allowed_hashes:Digestif.hash' list -> ?crls:Core.Filename.t -> Core.Filename.t -> unit -> t
Sourceval ca_dir : ?allowed_hashes:Digestif.hash' list -> ?crls:Core.Filename.t -> Core.Filename.t -> unit -> t
Sourceval cert_fingerprint : Digestif.hash' -> string -> t

The fingerprint can be collected from a browser or by invoking an openssl command like 'openssl x509 -in <pem_file> -noout -fingerprint -sha256'

Sourceval key_fingerprint : Digestif.hash' -> string -> t

The fingerprint can be collected from a browser or by invoking an openssl command like 'openssl x509 -in <pem_file> -noout -pubkey | openssl pkey -pubin -outform DER | openssl dgst -sha256'

Sourceval time : unit -> Ptime.t option

Async programs often don't use Ptime_clock, so this is provided as a convenience function. Relies on Unix.gettimeofday.

Sourceval to_authenticator : time:(unit -> Ptime.t option) -> t -> {Authenticator}7/shadowed/(fefbac88f0dda811f392287d3cc3f24e).t Async.Deferred.Or_error.t