Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Authenticator.ParamSourceval ca_file :
?allowed_hashes:Digestif.hash' list ->
?crls:Core.Filename.t ->
Core.Filename.t ->
unit ->
tval ca_dir :
?allowed_hashes:Digestif.hash' list ->
?crls:Core.Filename.t ->
Core.Filename.t ->
unit ->
tThe fingerprint can be collected from a browser or by invoking an openssl command like 'openssl x509 -in <pem_file> -noout -fingerprint -sha256'
The fingerprint can be collected from a browser or by invoking an openssl command like 'openssl x509 -in <pem_file> -noout -pubkey | openssl pkey -pubin -outform DER | openssl dgst -sha256'
Async programs often don't use Ptime_clock, so this is provided as a convenience function. Relies on Unix.gettimeofday.
val to_authenticator :
time:(unit -> Ptime.t option) ->
t ->
{Authenticator}7/shadowed/(fefbac88f0dda811f392287d3cc3f24e).t
Async.Deferred.Or_error.t